@@ -8,7 +8,7 @@ import time
 from pprint import pprint
 
 from cloudmesh.common.Tabulate import Printer
-from cloudmesh.common.systeminfo import systeminfo
+from cloudmesh.common.systeminfo import systeminfo as cm_systeminfo
 
 
 class StopWatch(object):
@@ -27,6 +27,8 @@ class StopWatch(object):
     timer_status = {}
     # records a dt
     timer_sum = {}
+    # msg
+    timer_msg = {}
 
     @classmethod
     def keys(cls):
@@ -40,14 +42,39 @@ class StopWatch(object):
 
         :param name: the name of the timer
         :type name: string
-        :param status: the name of a status
-        :type status: bool
+        :param value: value of the nameed of a status
+        :type value: bool
 
         """
         if cls.debug:
             print("Timer", name, "status", value)
         cls.timer_status[name] = value
 
+    @classmethod
+    def get_message(cls, name):
+        """
+        starts a timer with the given name.
+
+        :param name: the name of the timer
+        :type name: string
+
+        """
+        return cls.timer_msg[name]
+
+    @classmethod
+    def message(cls, name, value):
+        """
+        starts a timer with the given name.
+
+        :param name: the name of the timer
+        :type name: string
+        :param value: the value of the message
+        :type value: bool
+
+        """
+        cls.timer_msg[name] = value
+
+
     @classmethod
     def start(cls, name):
         """
@@ -63,9 +90,10 @@ class StopWatch(object):
         cls.timer_start[name] = time.time()
         cls.timer_end[name] = None
         cls.timer_status[name] = None
+        cls.timer_msg[name] = None
 
     @classmethod
-    def stop(cls, name):
+    def stop(cls, name, state=True):
         """
         stops the timer with a given name.
 
@@ -73,9 +101,10 @@ class StopWatch(object):
         :type name: string
         """
         cls.timer_end[name] = time.time()
-        #if cumulate:
+        # if cumulate:
         #    cls.timer_end[name] = cls.timer_end[name] + cls.timer_last[name]
-        cls.timer_sum[name] = cls.timer_sum[name]  +  cls.timer_end[name] - cls.timer_start[name]
+        cls.timer_sum[name] = cls.timer_sum[name] + cls.timer_end[name] - cls.timer_start[name]
+        cls.timer_status[name] = state
 
         if cls.debug:
             print("Timer", name, "stopped ...")
@@ -90,6 +119,7 @@ class StopWatch(object):
         """
         return cls.timer_status[name]
 
+    # noinspection PyPep8
     @classmethod
     def get(cls, name, digits=4):
         """
@@ -107,7 +137,7 @@ class StopWatch(object):
                 else:
                     cls.timer_elapsed[name] = diff
                 return cls.timer_elapsed[name]
-            except:
+            except:  # noqa: E722
                 return None
         else:
             return "undefined"
@@ -128,7 +158,7 @@ class StopWatch(object):
                     return round(diff, digits)
                 else:
                     return diff
-            except:
+            except:  # noqa: E722
                 return None
         else:
             return "undefined"
@@ -143,13 +173,14 @@ class StopWatch(object):
         cls.timer_sum.clear()
         cls.timer_status.clear()
         cls.timer_elapsed.clear()
+        cls.timer_msg.clear()
 
     @classmethod
     def print(cls, *args):
         """
         prints a timer. The first argument is the label if it exists, the last is the timer
-        :param args: label, name 
-        :return: 
+        :param args: label, name
+        :return:
         """
         if cls.verbose:
             if len(args) == 2:
@@ -171,13 +202,27 @@ class StopWatch(object):
                 **data)
         return s
 
+    @classmethod
+    def systeminfo(cls):
+        data_platform = cm_systeminfo()
+
+        data_platform['cpu_count'] = multiprocessing.cpu_count()
+
+        return Printer.attribute(
+            data_platform,
+            order=["Machine Attribute", "Value"],
+            output="table"
+        )
+
     @classmethod
     def benchmark(cls,
                   sysinfo=True,
                   csv=True,
                   prefix="# csv",
                   tag=None,
-                  sum=True):
+                  sum=True,
+                  node=None,
+                  user=None):
         """
         prints out all timers in a convenient benchmark table
         :return:
@@ -189,7 +234,7 @@ class StopWatch(object):
         #
 
         print()
-        data_platform = systeminfo()
+        data_platform = cm_systeminfo()
 
         data_platform['cpu_count'] = multiprocessing.cpu_count()
 
@@ -216,6 +261,7 @@ class StopWatch(object):
                     'time': StopWatch.get(timer, digits=3),
                     'sum': StopWatch.sum(timer, digits=3),
                     'status': StopWatch.get_status(timer),
+                    'msg': StopWatch.get_message(timer),
                     'timer': timer,
                     'tag': tag or ''
                 }
@@ -226,7 +272,13 @@ class StopWatch(object):
                                   "uname.machine",
                                   "platform.version",
                                   "sys.platform"]:
-                    data_timers[timer][attribute] = data_platform[attribute]
+                    if attribute == "user" and user is not None:
+                        data_timers[timer][attribute] = user
+                    elif attribute == "uname.node" and node is not None:
+                        data_timers[timer][attribute] = node
+                    else:
+                        data_timers[timer][attribute] = data_platform[attribute]
+
 
             # print(Printer.attribute(data_timers, header=["Command", "Time/s"]))
 
@@ -234,11 +286,9 @@ class StopWatch(object):
                 del data_timers['benchmark_start_stop']
 
             for key in data_timers:
-                if key != 'benchmark_start_stop' and data_timers[key][
-                    'status'] == None:
+                if key != 'benchmark_start_stop' and data_timers[key]['status'] is None:
                     data_timers[key]['status'] = "failed"
-                elif data_timers[key]['status'] != None and data_timers[key][
-                    'status'] == True:
+                elif data_timers[key]['status'] is not None and data_timers[key]['status']:
                     data_timers[key]['status'] = "ok"
 
             order = [
@@ -248,6 +298,7 @@ class StopWatch(object):
                 "sum",
                 "start",
                 "tag",
+                "msg",
                 "uname.node",
                 "user",
                 "uname.system",
@@ -261,6 +312,7 @@ class StopWatch(object):
                 "Sum",
                 "Start",
                 "tag",
+                "msg",
                 "Node",
                 "User",
                 "OS",
