@@ -3,23 +3,22 @@ Printing messages in a console
 """
 import textwrap
 import traceback
-import platform
 import colorama
 from colorama import Fore, Back, Style
 import os
 
-# from cloudmesh.common.variables import Variables
 
+# from cloudmesh.common.variables import Variables
 
 
 def indent(text, indent=2, width=128):
     """
     indents the given text by the indent specified and wrapping to the given width
-    
+
     :param text: the text to print
     :param indent: indent characters
     :param width: the width of the text
-    :return: 
+    :return:
     """
     return "\n".join(
         textwrap.wrap(text,
@@ -69,7 +68,7 @@ class Console(object):
         'BOLD': Style.BRIGHT,
         'NORMAL': Style.NORMAL
         # 'ENDC': '\033[0m',
-        #'BOLD': "\033[1m",
+        # 'BOLD': "\033[1m",
     }
 
     theme_bw = {
@@ -117,14 +116,13 @@ class Console(object):
         """
         os._exit(1)
 
-
     @classmethod
     def set_debug(cls, on=True):
         """
         sets debugging on or of
 
         :param on: if on debugging is set
-        :return: 
+        :return:
         """
         cls.debug = on
 
@@ -134,7 +132,7 @@ class Console(object):
         defines if the console messages are printed in color
 
         :param color: if True its printed in color
-        :return: 
+        :return:
         """
         if color:
             Console.theme = Console.theme_color
@@ -148,7 +146,7 @@ class Console(object):
         returns the default theme for printing console messages
 
         :param name: the name of the theme
-        :return: 
+        :return:
         """
         if name in Console.theme:
             return Console.theme[name]
@@ -162,7 +160,7 @@ class Console(object):
 
         :param message: the message to print
         :param width: teh width of the line
-        :return: 
+        :return:
         """
         return textwrap.fill(message, width=width)
 
@@ -172,7 +170,7 @@ class Console(object):
         prints a message
 
         :param message: the message to print
-        :return: 
+        :return:
         """
         str = " ".join(message)
         print(str)
@@ -187,7 +185,6 @@ class Console(object):
         for name in elements:
             print("*", name)
 
-
     @classmethod
     def error(cls, message, prefix=True, traceflag=False):
         """
@@ -196,11 +193,11 @@ class Console(object):
         :param message: the message
         :param prefix: a prefix for the message
         :param traceflag: if true the stack trace is retrieved and printed
-        :return: 
+        :return:
         """
         # print (message, prefix)
-        #variables = Variables()
-        #traceflag = traceflag or variables['trace']
+        # variables = Variables()
+        # traceflag = traceflag or variables['trace']
 
         message = message or ""
         if prefix:
@@ -228,7 +225,7 @@ class Console(object):
         :param message: the message
         :param prefix: if set to true it prints TODO: as prefix
         :param traceflag: if true the stack trace is retrieved and printed
-        :return: 
+        :return:
         """
         message = message or ""
         if prefix:
@@ -253,7 +250,7 @@ class Console(object):
         print a debug message
 
         :param message: the message
-        :return: 
+        :return:
         """
         message = message or ""
         if Console.color:
@@ -267,7 +264,7 @@ class Console(object):
         prints an informational message
 
         :param message: the message
-        :return: 
+        :return:
         """
         message = message or ""
         if Console.color:
@@ -281,7 +278,7 @@ class Console(object):
         prints a warning
 
         :param message: the message
-        :return: 
+        :return:
         """
         message = message or ""
         if Console.color:
@@ -295,7 +292,7 @@ class Console(object):
         prints an ok message
 
         :param message: the message<
-        :return: 
+        :return:
         """
         message = message or ""
         if Console.color:
@@ -311,15 +308,12 @@ class Console(object):
         :param color: the color as defined in the theme
         :param prefix: the prefix (a string)
         :param message: the message
-        :return: 
+        :return:
         """
         message = message or ""
         prefix = prefix or ""
 
-        print(Console.theme_color[color] +
-              prefix +
-              message +
-              Console.theme_color['ENDC'])
+        print(Console.theme_color[color] + prefix + message + Console.theme_color['ENDC'])
 
     @staticmethod
     def text(color='RED', prefix=None, message=None):
@@ -333,10 +327,7 @@ class Console(object):
         """
         message = message or ""
         prefix = prefix or ""
-        return (Console.theme[color] +
-                prefix +
-                message +
-                Console.theme['ENDC'])
+        return (Console.theme[color] + prefix + message + Console.theme['ENDC'])
 
 
 #
