@@ -1,6 +1,4 @@
 import subprocess
-import time
-import sys
 
 
 class run(object):
