@@ -7,19 +7,43 @@ from collections import OrderedDict
 import pip
 import psutil
 import humanize
+import re
+
 
 def sys_user():
-    if "COLAB_GPU" in  os.environ:
+    if "COLAB_GPU" in os.environ:
         return "collab"
     elif sys.platform == "win32":
         return os.environ["USERNAME"]
     else:
-        return os.environ["USER"]
+        try:
+            return os.environ["USER"]
+        except:
+            if os.environ["HOME"] == "/root":
+                return "root"
+    return "None"
+
+
+def get_platform():
+    if sys.platform == "darwin":
+        return "macos"
+    elif sys.platform == "win32":
+        return "windows"
+    try:
+        content = readfile('/etc/os-release')
+        if sys.platform == 'linux' and "raspbian" in content:
+            return "raspberry"
+        else:
+            return sys.platform
+    except:
+        return sys.platform
+
 
 def systeminfo():
     uname = platform.uname()
     mem = psutil.virtual_memory()
 
+    # noinspection PyPep8
     def add_binary(value):
         try:
             r = humanize.naturalsize(value, binary=True)
@@ -27,13 +51,32 @@ def systeminfo():
             r = ""
         return r
 
+    frequency = psutil.cpu_freq()
+
+    operating_system = get_platform()
+
+    description = ""
+    try:
+        if operating_system == "macos":
+            description = os.popen("sysctl -n machdep.cpu.brand_string").read()
+        elif operating_system == "win32":
+            description = platform.processor()
+        elif operating_system == "linux":
+            lines = readfile("/proc/cpuinfo").strip().splitlines()
+            for line in lines:
+                if "model name" in line:
+                    description = re.sub(".*model name.*:", "", line, 1)
+    except:
+        pass
+
+
     data = OrderedDict({
+        'cpu': description,
         'uname.system': uname.system,
         'uname.node': uname.node,
         'uname.release': uname.release,
         'uname.version': uname.version,
         'uname.machine': uname.machine,
-        'uname.system': uname.system,
         'uname.processor': uname.processor,
         'sys.platform': sys.platform,
         'python': sys.version,
@@ -41,6 +84,7 @@ def systeminfo():
         'python.pip': pip.__version__,
         'user': sys_user(),
         'mem.percent': str(mem.percent) + " %",
+        'frequency': frequency
     })
     for attribute in ["total",
                       "available",
