@@ -1,3 +1,4 @@
+import subprocess
 import collections
 import glob
 import inspect
@@ -11,17 +12,15 @@ from contextlib import contextmanager
 import sys
 import psutil
 import requests
-from  pathlib import Path
+from pathlib import Path
+from cloudmesh.common.console import Console
+import pyfiglet
 
 try:
     collectionsAbc = collections.abc
 except AttributeError:
     collectionsAbc = collections
 
-from pathlib import Path
-
-from cloudmesh.common.console import Console
-
 
 @contextmanager
 def tempdir(*args, **kwargs):
@@ -41,6 +40,7 @@ def tempdir(*args, **kwargs):
     finally:
         shutil.rmtree(d)
 
+
 def check_root(terminate=True):
     """
     Tests if the root user is used
@@ -56,6 +56,7 @@ def check_root(terminate=True):
         if terminate:
             sys.exit()
 
+
 def exponential_backoff(fn, sleeptime_s_max=30 * 60):
     """Calls `fn` until it returns True, with an exponentially increasing wait time between calls"""
 
@@ -71,10 +72,13 @@ def exponential_backoff(fn, sleeptime_s_max=30 * 60):
         if sleeptime_ms / 1000.0 > sleeptime_s_max:
             return False
 
+
 def download(source, destination, force=False):
     """
     Downloads the file from source to destination
 
+    For large files, see cloudmesh.common.Shell.download
+
     :param source: The http source
     :param destination: The destination in the file system
     :param force: If True the file will be downloaded even if
@@ -90,19 +94,20 @@ def download(source, destination, force=False):
         r = requests.get(source, allow_redirects=True)
         open(destination, 'wb').write(r.content)
 
+
 def search(lines, pattern):
     """
     return all lines that match the pattern
     #TODO: we need an example
-    
-    :param lines: 
-    :param pattern: 
-    :return: 
+
+    :param lines:
+    :param pattern:
+    :return:
     """
     p = pattern.replace("*", ".*")
     test = re.compile(p)
     result = []
-    for l in lines:
+    for l in lines:  # noqa: E741
         if test.search(l):
             result.append(l)
     return result
@@ -120,6 +125,8 @@ def grep(pattern, filename):
     except StopIteration:
         return ''
 
+
+# noinspection PyPep8
 def is_gitbash():
     """
     returns True if you run in a Windows gitbash
@@ -132,6 +139,7 @@ def is_gitbash():
     except:
         return False
 
+
 def is_powershell():
     """
     True if you run in powershell
@@ -143,6 +151,8 @@ def is_powershell():
     # powershell.exe for powershell
     # bash.exe for git bash
     return (psutil.Process(os.getppid()).name() == "powershell.exe")
+
+
 def is_cmd_exe():
     """
     return True if you run in a Windows CMD
@@ -157,6 +167,7 @@ def is_cmd_exe():
         except:
             return False
 
+
 def path_expand(text):
     """ returns a string with expanded variable.
 
@@ -174,11 +185,12 @@ def path_expand(text):
 
     return result
 
+
 def convert_from_unicode(data):
     """
     converts unicode data to a string
     :param data: the data to convert
-    :return: 
+    :return:
     """
     # if isinstance(data, basestring):
 
@@ -202,13 +214,12 @@ def yn_choice(message, default='y', tries=None):
     # http://stackoverflow.com/questions/3041986/python-command-line-yes-no-input"""
     choices = 'Y/n' if default.lower() in ('y', 'yes') else 'y/N'
     if tries is None:
-        choice = input("%s (%s) " % (message, choices))
+        choice = input(f"{message} ({choices}) ")
         values = ('y', 'yes', '') if default == 'y' else ('y', 'yes')
         return True if choice.strip().lower() in values else False
     else:
         while tries > 0:
-            choice = input(
-                "%s (%s) (%s)" % (message, choices, "'q' to discard"))
+            choice = input(f"{message} ({choices}) ('q' to discard)")
             choice = choice.strip().lower()
             if choice in ['y', 'yes']:
                 return True
@@ -219,7 +230,9 @@ def yn_choice(message, default='y', tries=None):
                 tries -= 1
 
 
-def banner(txt=None, c="-", prefix="#", debug=True, label=None, color=None):
+def str_banner(txt=None, c="-", prefix="#", debug=True, label=None,
+               color="BLUE", padding=False,
+               figlet=False, font="big"):
     """
     prints a banner of the form with a frame of # around the txt::
 
@@ -239,52 +252,50 @@ def banner(txt=None, c="-", prefix="#", debug=True, label=None, color=None):
     if debug:
         output = "\n"
         output += prefix + " " + 70 * c + "\n"
+        if padding:
+            output += prefix + "\n"
         if label is not None:
             output += prefix + " " + label + "\n"
             output += prefix + " " + 70 * c + "\n"
+
         if txt is not None:
+
+            if figlet:
+                txt = pyfiglet.figlet_format(txt, font=font)
+
             for line in txt.splitlines():
                 output += prefix + " " + line + "\n"
+            if padding:
+                output += prefix + "\n"
             output += prefix + " " + 70 * c + "\n"
-    if color is None:
-        color = "BLUE"
-
-    Console.cprint(color, "", output)
-
-
-def str_banner(txt=None, c="-", prefix= "#", debug=True, label=None, color=None):
-    """
-    prints a banner of the form with a frame of # around the txt::
-
-    # --------------------------
-    # txt
-    # --------------------------
-
-    :param color: prints in the given color
-    :param label: adds a label
-    :param debug: prints only if debug is true
-    :param txt: a text message to be printed
-    :type txt: string
-    :param c: the character used instead of c
-    :type c: character
-    """
-    output = ""
-    if debug:
-        output = "\n"
-        output += prefix + " " + 70 * c + "\n"
-        if label is not None:
-            output += prefix + " " + label + "\n"
-            output += prefix + " " + 70 * c + "\n"
-        if txt is not None:
-            for line in txt.splitlines():
-                output += prefix + " " + line + "\n"
-            output += prefix + " " + 70 * c + "\n"
-    if color is None:
-        color = "BLUE"
 
     return output
 
 
+def banner(txt=None, c="-", prefix="#", debug=True, label=None,
+           color="BLUE", padding=False,
+           figlet=False, font="big"):
+    """
+    prints a banner of the form with a frame of # around the txt::
+
+    # --------------------------
+    # txt
+    # --------------------------
+
+    :param color: prints in the given color
+    :param label: adds a label
+    :param debug: prints only if debug is true
+    :param txt: a text message to be printed
+    :type txt: string
+    :param c: the character used instead of c
+    :type c: character
+    :param padding: ads additional comment line around the text so the banner is larger
+    :type padding: bool
+    """
+
+    output = str_banner(txt=txt, c=c, prefix=prefix, debug=debug, label=label,
+                        color=color, padding=padding, figlet=figlet, font=font)
+    Console.cprint(color, "", output)
 
 
 # noinspection PyPep8Naming
@@ -307,7 +318,6 @@ def HEADING(txt=None, c="#", color="HEADER"):
     else:
         msg = "{}\n {} {} {}".format(txt, method, filename, line)
 
-
     print()
     banner(msg, c=c, color=color)
 
@@ -338,10 +348,10 @@ def auto_create_version(class_name, version, filename="__init__.py"):
     """
     creates a version number in the __init__.py file.
     it can be accessed with __version__
-    :param class_name: 
-    :param version: 
-    :param filename: 
-    :return: 
+    :param class_name:
+    :param version:
+    :param filename:
+    :return:
     """
     version_filename = Path(
         "{classname}/{filename}".format(classname=class_name,
@@ -398,12 +408,12 @@ def readfile(filename, mode='r'):
     """
     returns the content of a file
     :param filename: the filename
-    :return: 
+    :return:
     """
     if mode != 'r' and mode != 'rb':
-        Console.error( f"incorrect mode : expected 'r' or 'rb' given {mode}")
+        Console.error(f"incorrect mode : expected 'r' or 'rb' given {mode}")
     else:
-        with open(path_expand(filename), mode)as f:
+        with open(path_expand(filename), mode) as f:
             content = f.read()
             f.close()
         return content
@@ -414,13 +424,14 @@ def writefile(filename, content):
     writes the content into the file
     :param filename: the filename
     :param content: teh content
-    :return: 
+    :return:
     """
     with open(path_expand(filename), 'w') as outfile:
         outfile.write(content)
         outfile.truncate()
 
-def writefd(filename, content, mode='w', flags = os.O_RDWR|os.O_CREAT, mask=0o600):
+
+def writefd(filename, content, mode='w', flags=os.O_RDWR | os.O_CREAT, mask=0o600):
     """
     writes the content into the file and control permissions
     :param filename: the full or relative path to the filename
@@ -430,13 +441,39 @@ def writefd(filename, content, mode='w', flags = os.O_RDWR|os.O_CREAT, mask=0o60
     :param mask: the mask that the permissions will be applied to
     """
     if mode != 'w' and mode != 'wb':
-        Console.error( f"incorrect mode : expected 'w' or 'wb' given {mode}")
+        Console.error(f"incorrect mode : expected 'w' or 'wb' given {mode}")
 
     with os.fdopen(os.open(filename, flags, mask), mode) as outfile:
         outfile.write(content)
         outfile.truncate()
         outfile.close()
 
+
+def sudo_readfile(filename, split=True, trim=False):
+    """
+    Reads the content of the file as sudo and returns the result
+
+    :param filename: the filename
+    :type filename: str
+    :param split: uf true returns a list of lines
+    :type split: bool
+    :param trim: trim trailing whitespace. This is useful to
+                 prevent empty string entries when splitting by '\n'
+    :type trim: bool
+    :return: the content
+    :rtype: str or list
+    """
+    result = subprocess.getoutput(f"sudo cat {filename}")
+
+    if trim:
+        result = result.rstrip()
+
+    if split:
+        result = result.split('\n')
+
+    return result
+
+
 # Reference: http://interactivepython.org/runestone/static/everyday/2013/01/3_password.html
 def generate_password(length=8, lower=True, upper=True, number=True):
     """
@@ -445,7 +482,7 @@ def generate_password(length=8, lower=True, upper=True, number=True):
     :param lower: True of lower case characters are allowed
     :param upper: True if upper case characters are allowed
     :param number: True if numbers are allowed
-    :return: 
+    :return:
     """
     lletters = "abcdefghijklmnopqrstuvwxyz"
     uletters = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
